@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -40,12 +40,13 @@ import org.drools.workbench.screens.guided.dtable.client.widget.analysis.Decisio
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshActionsPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshAttributesPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshConditionsPanelEvent;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshMenusEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshMetaDataPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.lockmanager.GuidedDecisionTableLockManager;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.GridWidgetColumnFactory;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.converters.column.impl.GridWidgetColumnFactoryImpl;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.MoveColumnVetoException;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.utilities.EnumLoaderUtilities;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.guvnor.common.services.shared.metadata.model.Overview;
@@ -53,10 +54,10 @@ import org.gwtbootstrap3.client.ui.html.Text;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
-import org.junit.Ignore;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.AnalysisReportScreen;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracleFactory;
 import org.mockito.Mock;
@@ -67,10 +68,14 @@ import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.rpc.SessionInfo;
 import org.uberfire.security.authz.AuthorizationManager;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @WithClassesToStub({Text.class, DateTimeFormat.class})
 @RunWith(GwtMockitoTestRunner.class)
@@ -109,6 +114,9 @@ public class GuidedDecisionTablePresenter_AuditLogTest {
     @Mock
     private EventSourceMock<RefreshActionsPanelEvent> refreshActionsPanelEvent;
 
+    @Mock
+    private EventSourceMock<RefreshMenusEvent> refreshMenusEvent;
+
     @Mock
     private DecisionTableAnalyzerProvider decisionTableAnalyzerProvider;
 
@@ -132,7 +140,7 @@ public class GuidedDecisionTablePresenter_AuditLogTest {
     private List<BaseColumnFieldDiff> diffs;
 
     @Before
-    public void setup() throws MoveColumnVetoException {
+    public void setup() throws VetoException {
         setupPresenter();
 
         for (Entry<String, Boolean> entry : model.getAuditLog().getAuditLogFilter().getAcceptedTypes().entrySet()) {
@@ -161,6 +169,7 @@ public class GuidedDecisionTablePresenter_AuditLogTest {
                                                        refreshMetaDataPanelEvent,
                                                        refreshConditionsPanelEvent,
                                                        refreshActionsPanelEvent,
+                                                       refreshMenusEvent,
                                                        null,
                                                        null,
                                                        gridWidgetColumnFactory,
@@ -207,6 +216,7 @@ public class GuidedDecisionTablePresenter_AuditLogTest {
 
         dtPresenter.setContent(null,
                                mock(PlaceRequest.class),
+                               mock(AnalysisReportScreen.class),
                                dtContent,
                                modellerPresenter,
                                false);
@@ -214,7 +224,7 @@ public class GuidedDecisionTablePresenter_AuditLogTest {
     }
 
     @Test
-    public void updateColumnAddsToLog() throws MoveColumnVetoException {
+    public void updateColumnAddsToLog() throws VetoException {
         dtPresenter.updateColumn(new ActionCol52(),
                                  new ActionCol52());
         dtPresenter.updateColumn(new AttributeCol52(),
