@@ -27,20 +27,26 @@ import com.google.gwt.user.client.ui.IsWidget;
 import elemental2.promise.Promise;
 import org.drools.scenariosimulation.api.model.AbstractScesimData;
 import org.drools.scenariosimulation.api.model.AbstractScesimModel;
-import org.drools.scenariosimulation.api.model.AuditLog;
 import org.drools.scenariosimulation.api.model.Background;
 import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
 import org.drools.scenariosimulation.api.model.ScenarioWithIndex;
 import org.drools.scenariosimulation.api.model.ScesimModelDescriptor;
 import org.drools.scenariosimulation.api.model.Settings;
 import org.drools.scenariosimulation.api.model.Simulation;
+import org.drools.scenariosimulation.api.model.SimulationRunMetadata;
 import org.drools.workbench.screens.scenariosimulation.businesscentral.client.editor.strategies.BusinessCentralDMNDataManagementStrategy;
 import org.drools.workbench.screens.scenariosimulation.businesscentral.client.editor.strategies.BusinessCentralDMODataManagementStrategy;
+import org.drools.workbench.screens.scenariosimulation.businesscentral.client.handlers.ScenarioSimulationBusinessCentralDocksHandler;
+import org.drools.workbench.screens.scenariosimulation.businesscentral.client.rightpanel.coverage.CoverageReportPresenter;
+import org.drools.workbench.screens.scenariosimulation.businesscentral.client.rightpanel.coverage.CoverageReportView;
 import org.drools.workbench.screens.scenariosimulation.client.editor.ScenarioSimulationEditorPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.editor.ScenarioSimulationEditorWrapper;
+import org.drools.workbench.screens.scenariosimulation.client.editor.strategies.AbstractDMODataManagementStrategy;
 import org.drools.workbench.screens.scenariosimulation.client.editor.strategies.DataManagementStrategy;
 import org.drools.workbench.screens.scenariosimulation.client.enums.GridWidget;
+import org.drools.workbench.screens.scenariosimulation.client.handlers.AbstractScenarioSimulationDocksHandler;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ScenarioSimulationHasBusyIndicatorDefaultErrorCallback;
+import org.drools.workbench.screens.scenariosimulation.client.popup.CustomBusyPopup;
 import org.drools.workbench.screens.scenariosimulation.client.resources.i18n.ScenarioSimulationEditorConstants;
 import org.drools.workbench.screens.scenariosimulation.client.rightpanel.TestToolsPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.type.ScenarioSimulationResourceType;
@@ -77,12 +83,14 @@ import org.uberfire.ext.editor.commons.service.support.SupportsDelete;
 import org.uberfire.ext.editor.commons.service.support.SupportsRename;
 import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;
 import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
+import org.uberfire.ext.widgets.common.client.common.BusyPopup;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.lifecycle.OnMayClose;
 import org.uberfire.lifecycle.OnStartup;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
+import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.Menus;
 
 import static org.drools.workbench.screens.scenariosimulation.client.editor.ScenarioSimulationEditorPresenter.IDENTIFIER;
@@ -103,6 +111,8 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
     private Caller<DMNTypeService> dmnTypeService;
     private Caller<ImportExportService> importExportService;
     private Caller<RunnerReportService> runnerReportService;
+    private ScenarioSimulationBusinessCentralDocksHandler scenarioSimulationBusinessCentralDocksHandler;
+    protected SimulationRunResult lastRunResult;
 
     public ScenarioSimulationEditorBusinessCentralWrapper() {
         //Zero-parameter constructor for CDI proxies
@@ -116,7 +126,8 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
                                                           final PlaceManager placeManager,
                                                           final Caller<DMNTypeService> dmnTypeService,
                                                           final Caller<ImportExportService> importExportService,
-                                                          final Caller<RunnerReportService> runnerReportService) {
+                                                          final Caller<RunnerReportService> runnerReportService,
+                                                          final ScenarioSimulationBusinessCentralDocksHandler scenarioSimulationBusinessCentralDocksHandler) {
         super(scenarioSimulationEditorPresenter.getView());
         this.scenarioSimulationEditorPresenter = scenarioSimulationEditorPresenter;
         this.dmnTypeService = dmnTypeService;
@@ -127,15 +138,15 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
         this.oracleFactory = oracleFactory;
         this.placeManager = placeManager;
         this.type = scenarioSimulationEditorPresenter.getType();
+        this.scenarioSimulationBusinessCentralDocksHandler = scenarioSimulationBusinessCentralDocksHandler;
     }
 
     @OnStartup
     public void onStartup(final ObservablePath path,
                           final PlaceRequest place) {
-        super.init(path,
-                   place,
-                   type);
-        scenarioSimulationEditorPresenter.init(this, (ObservablePath) place.getPath());
+        super.init(path, place, type);
+        scenarioSimulationEditorPresenter.setWrapper(this);
+        scenarioSimulationEditorPresenter.setPath(path);
     }
 
     @OnClose
@@ -181,6 +192,13 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
         final DefaultPlaceRequest placeRequest = new DefaultPlaceRequest(TestToolsPresenter.IDENTIFIER);
         scenarioSimulationEditorPresenter.showDocks(placeManager.getStatus(placeRequest));
         registerTestToolsCallback();
+        /* Managing TestRunner Report */
+        wrappedRegisterDock(ScenarioSimulationBusinessCentralDocksHandler.TEST_RUNNER_REPORTING_PANEL,
+                            scenarioSimulationBusinessCentralDocksHandler.getTestRunnerReportingPanelWidget());
+        /* It Loads last run info, it exits */
+        if (lastRunResult != null) {
+            scenarioSimulationBusinessCentralDocksHandler.updateTestRunnerReportingPanelResult(lastRunResult.getTestResultMessage());
+        }
     }
 
     @Override
@@ -196,15 +214,18 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
     }
 
     @Override
-    public void onExportToCsv(RemoteCallback<Object> exportCallBack, ScenarioSimulationHasBusyIndicatorDefaultErrorCallback scenarioSimulationHasBusyIndicatorDefaultErrorCallback, AbstractScesimModel<? extends AbstractScesimData> scesimModel) {
+    public void onExportToCsv(RemoteCallback<String> exportCallBack, ScenarioSimulationHasBusyIndicatorDefaultErrorCallback scenarioSimulationHasBusyIndicatorDefaultErrorCallback, AbstractScesimModel<? extends AbstractScesimData> scesimModel) {
         importExportService.call(exportCallBack, scenarioSimulationHasBusyIndicatorDefaultErrorCallback)
                 .exportScesimModel(CSV, scesimModel);
     }
 
     @Override
-    public void onDownloadReportToCsv(RemoteCallback<Object> exportCallBack, ScenarioSimulationHasBusyIndicatorDefaultErrorCallback scenarioSimulationHasBusyIndicatorDefaultErrorCallback, AuditLog auditLog) {
+    public void onDownloadReportToCsv(RemoteCallback<String> exportCallBack,
+                                      ScenarioSimulationHasBusyIndicatorDefaultErrorCallback scenarioSimulationHasBusyIndicatorDefaultErrorCallback,
+                                      SimulationRunMetadata simulationRunMetadata,
+                                      ScenarioSimulationModel.Type modelType) {
         runnerReportService.call(exportCallBack, scenarioSimulationHasBusyIndicatorDefaultErrorCallback)
-                .getReport(auditLog);
+                .getReport(simulationRunMetadata, modelType);
     }
 
     @Override
@@ -224,11 +245,6 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
                              background);
     }
 
-    @Override
-    public void wrappedSave(String commitMessage) {
-        save(commitMessage);
-    }
-
     @Override
     public Integer getOriginalHash() {
         return originalHash;
@@ -248,6 +264,12 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
                 .validate(simulation, settings, versionRecordManager.getCurrentPath());
     }
 
+    @Override
+    public void onRefreshedModelContent(SimulationRunResult testResult) {
+        this.lastRunResult = testResult;
+        scenarioSimulationBusinessCentralDocksHandler.updateTestRunnerReportingPanelResult(testResult.getTestResultMessage());
+    }
+
     /**
      * This method is called when the main grid tab (Model) is focused
      */
@@ -314,6 +336,28 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
         }
     }
 
+    @Override
+    public AbstractScenarioSimulationDocksHandler getScenarioSimulationDocksHandler() {
+        return scenarioSimulationBusinessCentralDocksHandler;
+    }
+
+    @Override
+    public ScenarioSimulationEditorPresenter getScenarioSimulationEditorPresenter() {
+        return scenarioSimulationEditorPresenter;
+    }
+
+    @Override
+    public void populateDocks(String identifier) {
+        if (CoverageReportPresenter.IDENTIFIER.equals(identifier)) {
+            scenarioSimulationBusinessCentralDocksHandler.getCoverageReportPresenter().ifPresent(presenter -> {
+                setCoverageReport(presenter);
+                presenter.setCurrentPath(scenarioSimulationEditorPresenter.getPath());
+            });
+        } else {
+            ScenarioSimulationEditorWrapper.super.populateDocks(identifier);
+        }
+    }
+
     protected void registerTestToolsCallback() {
         placeManager.registerOnOpenCallback(new DefaultPlaceRequest(TestToolsPresenter.IDENTIFIER), scenarioSimulationEditorPresenter.getPopulateTestToolsCommand());
     }
@@ -322,10 +366,6 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
         placeManager.getOnOpenCallbacks(new DefaultPlaceRequest(TestToolsPresenter.IDENTIFIER)).remove(scenarioSimulationEditorPresenter.getPopulateTestToolsCommand());
     }
 
-    protected void setSaveEnabled(boolean toSet) {
-        scenarioSimulationEditorPresenter.setSaveEnabled(toSet);
-    }
-
     /**
      * If you want to customize the menu override this method.
      */
@@ -333,9 +373,9 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
     protected Promise<Void> makeMenuBar() {
         scenarioSimulationEditorPresenter.makeMenuBar(fileMenuBuilder);
         if (workbenchContext.getActiveWorkspaceProject().isPresent()) {
-            final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().get();
+            final WorkspaceProject activeProject = workbenchContext.getActiveWorkspaceProject().orElseThrow(IllegalStateException::new);
             return projectController.canUpdateProject(activeProject).then(canUpdateProject -> {
-                if (canUpdateProject) {
+                if (Boolean.TRUE.equals(canUpdateProject)) {
                     addSave(fileMenuBuilder);
                     addCopy(fileMenuBuilder);
                     addRename(fileMenuBuilder);
@@ -343,7 +383,6 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
                 }
                 addDownloadMenuItem(fileMenuBuilder);
                 addCommonActions(fileMenuBuilder);
-                setSaveEnabled(canUpdateProject);
                 return promises.resolve();
             });
         }
@@ -383,7 +422,19 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
     protected void loadContent() {
         scenarioSimulationEditorPresenter.loadContent();
         service.call(getModelSuccessCallback(),
-                     getNoSuchFileExceptionErrorCallback()).loadContent(versionRecordManager.getCurrentPath());
+                     getLoadContentErrorCallback()).loadContent(versionRecordManager.getCurrentPath());
+    }
+
+    protected ErrorCallback<Boolean> getLoadContentErrorCallback() {
+        return (message, exception) -> {
+            CustomBusyPopup.close();
+            BusyPopup.close();
+            scenarioSimulationEditorPresenter.sendNotification(ScenarioSimulationEditorConstants.INSTANCE.loadContentFailedNotification()
+                                                                       + exception.getMessage(),
+                                                               NotificationEvent.NotificationType.ERROR);
+            placeManager.forceClosePlace(place);
+            return false;
+        };
     }
 
     @Override
@@ -448,4 +499,17 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
     private RemoteCallback<ScenarioSimulationModelContent> getModelSuccessCallback() {
         return this::getModelSuccessCallbackMethod;
     }
+
+    protected void setCoverageReport(CoverageReportView.Presenter presenter) {
+        ScenarioSimulationModel.Type modelType = scenarioSimulationEditorPresenter.getDataManagementStrategy() instanceof AbstractDMODataManagementStrategy ? ScenarioSimulationModel.Type.RULE : ScenarioSimulationModel.Type.DMN;
+        SimulationRunMetadata simulationRunMetadata = lastRunResult != null ? lastRunResult.getSimulationRunMetadata() : null;
+        presenter.populateCoverageReport(modelType, simulationRunMetadata);
+        if (simulationRunMetadata != null && simulationRunMetadata.getAuditLog() != null) {
+            presenter.setDownloadReportCommand(() -> onDownloadReportToCsv(
+                scenarioSimulationEditorPresenter.getExportCallBack(),
+                new ScenarioSimulationHasBusyIndicatorDefaultErrorCallback(scenarioSimulationEditorPresenter.getView()),
+                simulationRunMetadata,
+                modelType));
+        }
+    }
 }
